Bantam is a Python package for building http-based micro-services.
It abstracts away any knowledge of routes, mappings and translations
between javascript and Python.  It even provides a means of
auto-generating the javascript client interface to you app
on the fly and serve it to web-based/javascript-based clients.

See https://nak.github.io/bantam_docs/ for details.